@@ -39,7 +39,6 @@
 			this.m_cbKeyFile = new System.Windows.Forms.CheckBox();
 			this.m_cbUserAccount = new System.Windows.Forms.CheckBox();
 			this.m_lblWindowsAccDesc = new System.Windows.Forms.Label();
-			this.m_lblKeyFileInfo = new System.Windows.Forms.Label();
 			this.m_btnCancel = new System.Windows.Forms.Button();
 			this.m_btnCreate = new System.Windows.Forms.Button();
 			this.m_ttRect = new System.Windows.Forms.ToolTip(this.components);
@@ -48,15 +47,22 @@
 			this.m_btnOpenKeyFile = new System.Windows.Forms.Button();
 			this.m_btnHelp = new System.Windows.Forms.Button();
 			this.m_lblSeparator = new System.Windows.Forms.Label();
-			this.m_pbPasswordQuality = new KeePass.UI.QualityProgressBar();
 			this.m_lblEstimatedQuality = new System.Windows.Forms.Label();
 			this.m_lblQualityInfo = new System.Windows.Forms.Label();
 			this.m_bannerImage = new System.Windows.Forms.PictureBox();
 			this.m_cmbKeyFile = new System.Windows.Forms.ComboBox();
 			this.m_lblWindowsAccDesc2 = new System.Windows.Forms.Label();
 			this.m_picAccWarning = new System.Windows.Forms.PictureBox();
+			this.m_cbExpert = new System.Windows.Forms.CheckBox();
+			this.m_picKeyFileWarning = new System.Windows.Forms.PictureBox();
+			this.m_lblKeyFileWarning = new System.Windows.Forms.Label();
+			this.m_lnkKeyFile = new System.Windows.Forms.LinkLabel();
+			this.m_lnkUserAccount = new System.Windows.Forms.LinkLabel();
+			this.m_pbPasswordQuality = new KeePass.UI.QualityProgressBar();
+			this.m_lblKeyFileInfo = new System.Windows.Forms.Label();
 			((System.ComponentModel.ISupportInitialize)(this.m_bannerImage)).BeginInit();
 			((System.ComponentModel.ISupportInitialize)(this.m_picAccWarning)).BeginInit();
+			((System.ComponentModel.ISupportInitialize)(this.m_picKeyFileWarning)).BeginInit();
 			this.SuspendLayout();
 			// 
 			// m_lblIntro
@@ -64,7 +70,7 @@
 			this.m_lblIntro.Location = new System.Drawing.Point(9, 72);
 			this.m_lblIntro.Name = "m_lblIntro";
 			this.m_lblIntro.Size = new System.Drawing.Size(498, 13);
-			this.m_lblIntro.TabIndex = 19;
+			this.m_lblIntro.TabIndex = 22;
 			this.m_lblIntro.Text = "Specify the composite master key, which will be used to encrypt the database.";
 			// 
 			// m_lblMultiInfo
@@ -72,7 +78,7 @@
 			this.m_lblMultiInfo.Location = new System.Drawing.Point(9, 93);
 			this.m_lblMultiInfo.Name = "m_lblMultiInfo";
 			this.m_lblMultiInfo.Size = new System.Drawing.Size(498, 42);
-			this.m_lblMultiInfo.TabIndex = 20;
+			this.m_lblMultiInfo.TabIndex = 23;
 			this.m_lblMultiInfo.Text = resources.GetString("m_lblMultiInfo.Text");
 			// 
 			// m_cbPassword
@@ -81,8 +87,8 @@
 			this.m_cbPassword.Location = new System.Drawing.Point(12, 147);
 			this.m_cbPassword.Name = "m_cbPassword";
 			this.m_cbPassword.Size = new System.Drawing.Size(109, 17);
-			this.m_cbPassword.TabIndex = 21;
-			this.m_cbPassword.Text = "Master password:";
+			this.m_cbPassword.TabIndex = 24;
+			this.m_cbPassword.Text = "Master &password:";
 			this.m_cbPassword.UseVisualStyleBackColor = true;
 			this.m_cbPassword.CheckedChanged += new System.EventHandler(this.OnCheckedPassword);
 			// 
@@ -114,50 +120,41 @@
 			// m_cbKeyFile
 			// 
 			this.m_cbKeyFile.AutoSize = true;
-			this.m_cbKeyFile.Location = new System.Drawing.Point(12, 223);
+			this.m_cbKeyFile.Location = new System.Drawing.Point(12, 249);
 			this.m_cbKeyFile.Name = "m_cbKeyFile";
 			this.m_cbKeyFile.Size = new System.Drawing.Size(112, 17);
-			this.m_cbKeyFile.TabIndex = 7;
-			this.m_cbKeyFile.Text = "Key file / provider:";
+			this.m_cbKeyFile.TabIndex = 8;
+			this.m_cbKeyFile.Text = "&Key file / provider:";
 			this.m_cbKeyFile.UseVisualStyleBackColor = true;
 			this.m_cbKeyFile.CheckedChanged += new System.EventHandler(this.OnCheckedKeyFile);
 			// 
 			// m_cbUserAccount
 			// 
 			this.m_cbUserAccount.AutoSize = true;
-			this.m_cbUserAccount.Location = new System.Drawing.Point(12, 308);
+			this.m_cbUserAccount.Location = new System.Drawing.Point(12, 391);
 			this.m_cbUserAccount.Name = "m_cbUserAccount";
 			this.m_cbUserAccount.Size = new System.Drawing.Size(135, 17);
-			this.m_cbUserAccount.TabIndex = 12;
-			this.m_cbUserAccount.Text = "Windows user account";
+			this.m_cbUserAccount.TabIndex = 14;
+			this.m_cbUserAccount.Text = "Windows &user account";
 			this.m_cbUserAccount.UseVisualStyleBackColor = true;
 			this.m_cbUserAccount.CheckedChanged += new System.EventHandler(this.OnWinUserCheckedChanged);
 			// 
 			// m_lblWindowsAccDesc
 			// 
-			this.m_lblWindowsAccDesc.Location = new System.Drawing.Point(28, 328);
+			this.m_lblWindowsAccDesc.Location = new System.Drawing.Point(28, 411);
 			this.m_lblWindowsAccDesc.Name = "m_lblWindowsAccDesc";
 			this.m_lblWindowsAccDesc.Size = new System.Drawing.Size(479, 27);
-			this.m_lblWindowsAccDesc.TabIndex = 13;
-			this.m_lblWindowsAccDesc.Text = "This source uses data of the current Windows user. This data does not change when" +
-				" the Windows account password changes.";
-			// 
-			// m_lblKeyFileInfo
-			// 
-			this.m_lblKeyFileInfo.Location = new System.Drawing.Point(28, 273);
-			this.m_lblKeyFileInfo.Name = "m_lblKeyFileInfo";
-			this.m_lblKeyFileInfo.Size = new System.Drawing.Size(479, 28);
-			this.m_lblKeyFileInfo.TabIndex = 11;
-			this.m_lblKeyFileInfo.Text = "Create a new key file or browse your disks for an existing one. If you have insta" +
-				"lled a key provider plugin, it is also listed in this combo box.";
+			this.m_lblWindowsAccDesc.TabIndex = 15;
+			this.m_lblWindowsAccDesc.Text = "This source uses data of the current Windows user account. This data does not cha" +
+				"nge when the account password changes.";
 			// 
 			// m_btnCancel
 			// 
 			this.m_btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
-			this.m_btnCancel.Location = new System.Drawing.Point(432, 430);
+			this.m_btnCancel.Location = new System.Drawing.Point(432, 542);
 			this.m_btnCancel.Name = "m_btnCancel";
 			this.m_btnCancel.Size = new System.Drawing.Size(75, 23);
-			this.m_btnCancel.TabIndex = 18;
+			this.m_btnCancel.TabIndex = 20;
 			this.m_btnCancel.Text = "Cancel";
 			this.m_btnCancel.TextImageRelation = System.Windows.Forms.TextImageRelation.ImageBeforeText;
 			this.m_btnCancel.UseVisualStyleBackColor = true;
@@ -166,10 +163,10 @@
 			// m_btnCreate
 			// 
 			this.m_btnCreate.DialogResult = System.Windows.Forms.DialogResult.OK;
-			this.m_btnCreate.Location = new System.Drawing.Point(351, 430);
+			this.m_btnCreate.Location = new System.Drawing.Point(351, 542);
 			this.m_btnCreate.Name = "m_btnCreate";
 			this.m_btnCreate.Size = new System.Drawing.Size(75, 23);
-			this.m_btnCreate.TabIndex = 17;
+			this.m_btnCreate.TabIndex = 19;
 			this.m_btnCreate.Text = "OK";
 			this.m_btnCreate.TextImageRelation = System.Windows.Forms.TextImageRelation.ImageBeforeText;
 			this.m_btnCreate.UseVisualStyleBackColor = true;
@@ -189,10 +186,10 @@
 			// m_btnSaveKeyFile
 			// 
 			this.m_btnSaveKeyFile.Image = global::KeePass.Properties.Resources.B15x14_FileNew;
-			this.m_btnSaveKeyFile.Location = new System.Drawing.Point(341, 247);
+			this.m_btnSaveKeyFile.Location = new System.Drawing.Point(341, 273);
 			this.m_btnSaveKeyFile.Name = "m_btnSaveKeyFile";
 			this.m_btnSaveKeyFile.Size = new System.Drawing.Size(80, 23);
-			this.m_btnSaveKeyFile.TabIndex = 9;
+			this.m_btnSaveKeyFile.TabIndex = 10;
 			this.m_btnSaveKeyFile.Text = " &Create...";
 			this.m_btnSaveKeyFile.TextImageRelation = System.Windows.Forms.TextImageRelation.ImageBeforeText;
 			this.m_btnSaveKeyFile.UseVisualStyleBackColor = true;
@@ -201,10 +198,10 @@
 			// m_btnOpenKeyFile
 			// 
 			this.m_btnOpenKeyFile.Image = global::KeePass.Properties.Resources.B16x16_Folder_Blue_Open;
-			this.m_btnOpenKeyFile.Location = new System.Drawing.Point(427, 247);
+			this.m_btnOpenKeyFile.Location = new System.Drawing.Point(427, 273);
 			this.m_btnOpenKeyFile.Name = "m_btnOpenKeyFile";
 			this.m_btnOpenKeyFile.Size = new System.Drawing.Size(80, 23);
-			this.m_btnOpenKeyFile.TabIndex = 10;
+			this.m_btnOpenKeyFile.TabIndex = 11;
 			this.m_btnOpenKeyFile.Text = " &Browse...";
 			this.m_btnOpenKeyFile.TextImageRelation = System.Windows.Forms.TextImageRelation.ImageBeforeText;
 			this.m_btnOpenKeyFile.UseVisualStyleBackColor = true;
@@ -212,10 +209,10 @@
 			// 
 			// m_btnHelp
 			// 
-			this.m_btnHelp.Location = new System.Drawing.Point(12, 430);
+			this.m_btnHelp.Location = new System.Drawing.Point(12, 542);
 			this.m_btnHelp.Name = "m_btnHelp";
 			this.m_btnHelp.Size = new System.Drawing.Size(75, 23);
-			this.m_btnHelp.TabIndex = 16;
+			this.m_btnHelp.TabIndex = 21;
 			this.m_btnHelp.Text = "&Help";
 			this.m_btnHelp.UseVisualStyleBackColor = true;
 			this.m_btnHelp.Click += new System.EventHandler(this.OnBtnHelp);
@@ -223,18 +220,10 @@
 			// m_lblSeparator
 			// 
 			this.m_lblSeparator.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
-			this.m_lblSeparator.Location = new System.Drawing.Point(0, 422);
+			this.m_lblSeparator.Location = new System.Drawing.Point(0, 531);
 			this.m_lblSeparator.Name = "m_lblSeparator";
 			this.m_lblSeparator.Size = new System.Drawing.Size(519, 2);
-			this.m_lblSeparator.TabIndex = 15;
-			// 
-			// m_pbPasswordQuality
-			// 
-			this.m_pbPasswordQuality.Location = new System.Drawing.Point(150, 197);
-			this.m_pbPasswordQuality.Name = "m_pbPasswordQuality";
-			this.m_pbPasswordQuality.Size = new System.Drawing.Size(269, 16);
-			this.m_pbPasswordQuality.TabIndex = 5;
-			this.m_pbPasswordQuality.TabStop = false;
+			this.m_lblSeparator.TabIndex = 18;
 			// 
 			// m_lblEstimatedQuality
 			// 
@@ -267,37 +256,112 @@
 			// 
 			this.m_cmbKeyFile.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
 			this.m_cmbKeyFile.FormattingEnabled = true;
-			this.m_cmbKeyFile.Location = new System.Drawing.Point(150, 220);
+			this.m_cmbKeyFile.Location = new System.Drawing.Point(150, 246);
 			this.m_cmbKeyFile.MaxDropDownItems = 16;
 			this.m_cmbKeyFile.Name = "m_cmbKeyFile";
-			this.m_cmbKeyFile.Size = new System.Drawing.Size(357, 21);
-			this.m_cmbKeyFile.TabIndex = 8;
+			this.m_cmbKeyFile.Size = new System.Drawing.Size(356, 21);
+			this.m_cmbKeyFile.TabIndex = 9;
 			this.m_cmbKeyFile.SelectedIndexChanged += new System.EventHandler(this.OnKeyFileSelectedIndexChanged);
 			// 
 			// m_lblWindowsAccDesc2
 			// 
-			this.m_lblWindowsAccDesc2.Location = new System.Drawing.Point(53, 359);
+			this.m_lblWindowsAccDesc2.Location = new System.Drawing.Point(53, 446);
 			this.m_lblWindowsAccDesc2.Name = "m_lblWindowsAccDesc2";
-			this.m_lblWindowsAccDesc2.Size = new System.Drawing.Size(451, 55);
-			this.m_lblWindowsAccDesc2.TabIndex = 14;
+			this.m_lblWindowsAccDesc2.Size = new System.Drawing.Size(454, 54);
+			this.m_lblWindowsAccDesc2.TabIndex = 16;
 			this.m_lblWindowsAccDesc2.Text = resources.GetString("m_lblWindowsAccDesc2.Text");
 			// 
 			// m_picAccWarning
 			// 
-			this.m_picAccWarning.Location = new System.Drawing.Point(31, 359);
+			this.m_picAccWarning.Location = new System.Drawing.Point(31, 446);
 			this.m_picAccWarning.Name = "m_picAccWarning";
 			this.m_picAccWarning.Size = new System.Drawing.Size(16, 16);
 			this.m_picAccWarning.SizeMode = System.Windows.Forms.PictureBoxSizeMode.StretchImage;
 			this.m_picAccWarning.TabIndex = 22;
 			this.m_picAccWarning.TabStop = false;
 			// 
+			// m_cbExpert
+			// 
+			this.m_cbExpert.AutoSize = true;
+			this.m_cbExpert.Location = new System.Drawing.Point(12, 223);
+			this.m_cbExpert.Name = "m_cbExpert";
+			this.m_cbExpert.Size = new System.Drawing.Size(125, 17);
+			this.m_cbExpert.TabIndex = 7;
+			this.m_cbExpert.Text = "Show &expert options:";
+			this.m_cbExpert.UseVisualStyleBackColor = true;
+			this.m_cbExpert.CheckedChanged += new System.EventHandler(this.OnExpertCheckedChanged);
+			// 
+			// m_picKeyFileWarning
+			// 
+			this.m_picKeyFileWarning.Location = new System.Drawing.Point(31, 334);
+			this.m_picKeyFileWarning.Name = "m_picKeyFileWarning";
+			this.m_picKeyFileWarning.Size = new System.Drawing.Size(16, 16);
+			this.m_picKeyFileWarning.SizeMode = System.Windows.Forms.PictureBoxSizeMode.StretchImage;
+			this.m_picKeyFileWarning.TabIndex = 24;
+			this.m_picKeyFileWarning.TabStop = false;
+			// 
+			// m_lblKeyFileWarning
+			// 
+			this.m_lblKeyFileWarning.Location = new System.Drawing.Point(53, 334);
+			this.m_lblKeyFileWarning.Name = "m_lblKeyFileWarning";
+			this.m_lblKeyFileWarning.Size = new System.Drawing.Size(454, 28);
+			this.m_lblKeyFileWarning.TabIndex = 12;
+			this.m_lblKeyFileWarning.Text = "If the key file is lost or its contents are changed, the database cannot be opene" +
+				"d anymore. You should create a backup of the key file.";
+			// 
+			// m_lnkKeyFile
+			// 
+			this.m_lnkKeyFile.AutoSize = true;
+			this.m_lnkKeyFile.Location = new System.Drawing.Point(53, 366);
+			this.m_lnkKeyFile.Name = "m_lnkKeyFile";
+			this.m_lnkKeyFile.Size = new System.Drawing.Size(159, 13);
+			this.m_lnkKeyFile.TabIndex = 13;
+			this.m_lnkKeyFile.TabStop = true;
+			this.m_lnkKeyFile.Text = "More information about key files.";
+			this.m_lnkKeyFile.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.OnKeyFileLinkClicked);
+			// 
+			// m_lnkUserAccount
+			// 
+			this.m_lnkUserAccount.AutoSize = true;
+			this.m_lnkUserAccount.Location = new System.Drawing.Point(53, 504);
+			this.m_lnkUserAccount.Name = "m_lnkUserAccount";
+			this.m_lnkUserAccount.Size = new System.Drawing.Size(235, 13);
+			this.m_lnkUserAccount.TabIndex = 17;
+			this.m_lnkUserAccount.TabStop = true;
+			this.m_lnkUserAccount.Text = "More information about Windows user accounts.";
+			this.m_lnkUserAccount.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.OnUserAccountLinkClicked);
+			// 
+			// m_pbPasswordQuality
+			// 
+			this.m_pbPasswordQuality.Location = new System.Drawing.Point(150, 197);
+			this.m_pbPasswordQuality.Name = "m_pbPasswordQuality";
+			this.m_pbPasswordQuality.Size = new System.Drawing.Size(269, 16);
+			this.m_pbPasswordQuality.TabIndex = 5;
+			this.m_pbPasswordQuality.TabStop = false;
+			// 
+			// m_lblKeyFileInfo
+			// 
+			this.m_lblKeyFileInfo.Location = new System.Drawing.Point(28, 299);
+			this.m_lblKeyFileInfo.Name = "m_lblKeyFileInfo";
+			this.m_lblKeyFileInfo.Size = new System.Drawing.Size(479, 27);
+			this.m_lblKeyFileInfo.TabIndex = 25;
+			this.m_lblKeyFileInfo.Text = "A key file can be used as part of the master key; it does not store any database " +
+				"data. If an attacker has access to the key file, it does not provide any protect" +
+				"ion.";
+			// 
 			// KeyCreationForm
 			// 
 			this.AcceptButton = this.m_btnCreate;
 			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
 			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
 			this.CancelButton = this.m_btnCancel;
-			this.ClientSize = new System.Drawing.Size(519, 464);
+			this.ClientSize = new System.Drawing.Size(519, 576);
+			this.Controls.Add(this.m_lblKeyFileInfo);
+			this.Controls.Add(this.m_lnkUserAccount);
+			this.Controls.Add(this.m_lnkKeyFile);
+			this.Controls.Add(this.m_lblKeyFileWarning);
+			this.Controls.Add(this.m_picKeyFileWarning);
+			this.Controls.Add(this.m_cbExpert);
 			this.Controls.Add(this.m_picAccWarning);
 			this.Controls.Add(this.m_lblWindowsAccDesc2);
 			this.Controls.Add(this.m_cmbKeyFile);
@@ -306,7 +370,6 @@
 			this.Controls.Add(this.m_pbPasswordQuality);
 			this.Controls.Add(this.m_lblSeparator);
 			this.Controls.Add(this.m_btnHelp);
-			this.Controls.Add(this.m_lblKeyFileInfo);
 			this.Controls.Add(this.m_lblWindowsAccDesc);
 			this.Controls.Add(this.m_cbHidePassword);
 			this.Controls.Add(this.m_bannerImage);
@@ -336,6 +399,7 @@
 			this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.OnFormClosing);
 			((System.ComponentModel.ISupportInitialize)(this.m_bannerImage)).EndInit();
 			((System.ComponentModel.ISupportInitialize)(this.m_picAccWarning)).EndInit();
+			((System.ComponentModel.ISupportInitialize)(this.m_picKeyFileWarning)).EndInit();
 			this.ResumeLayout(false);
 			this.PerformLayout();
 
@@ -358,7 +422,6 @@
 		private System.Windows.Forms.PictureBox m_bannerImage;
 		private System.Windows.Forms.CheckBox m_cbHidePassword;
 		private System.Windows.Forms.Label m_lblWindowsAccDesc;
-		private System.Windows.Forms.Label m_lblKeyFileInfo;
 		private System.Windows.Forms.ToolTip m_ttRect;
 		private System.Windows.Forms.Button m_btnHelp;
 		private System.Windows.Forms.Label m_lblSeparator;
@@ -368,5 +431,11 @@
 		private System.Windows.Forms.ComboBox m_cmbKeyFile;
 		private System.Windows.Forms.Label m_lblWindowsAccDesc2;
 		private System.Windows.Forms.PictureBox m_picAccWarning;
+		private System.Windows.Forms.CheckBox m_cbExpert;
+		private System.Windows.Forms.PictureBox m_picKeyFileWarning;
+		private System.Windows.Forms.Label m_lblKeyFileWarning;
+		private System.Windows.Forms.LinkLabel m_lnkKeyFile;
+		private System.Windows.Forms.LinkLabel m_lnkUserAccount;
+		private System.Windows.Forms.Label m_lblKeyFileInfo;
 	}
 }
\ No newline at end of file
