@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -204,28 +204,28 @@ namespace KeePass.Forms
 				}
 
 				byte[] pb = m_icgPassword.GetPasswordUtf8();
-
-				uint uMinQual = Program.Config.Security.MasterPassword.MinimumQuality;
-				if(QualityEstimation.EstimatePasswordBits(pb) < uMinQual)
+				try
 				{
-					string strMQ = KPRes.MasterPasswordMinQualityFailed;
-					strMQ = strMQ.Replace(@"{PARAM}", uMinQual.ToString());
-					MessageService.ShowWarning(strMQ);
-					MemUtil.ZeroByteArray(pb);
-					return false;
-				}
+					uint uMinQual = Program.Config.Security.MasterPassword.MinimumQuality;
+					if(QualityEstimation.EstimatePasswordBits(pb) < uMinQual)
+					{
+						string strMQ = KPRes.MasterPasswordMinQualityFailed;
+						strMQ = strMQ.Replace(@"{PARAM}", uMinQual.ToString());
+						MessageService.ShowWarning(strMQ);
+						return false;
+					}
 
-				string strValRes = Program.KeyValidatorPool.Validate(pb,
-					KeyValidationType.MasterPassword);
-				if(strValRes != null)
-				{
-					MessageService.ShowWarning(strValRes);
-					MemUtil.ZeroByteArray(pb);
-					return false;
-				}
+					string strValRes = Program.KeyValidatorPool.Validate(pb,
+						KeyValidationType.MasterPassword);
+					if(strValRes != null)
+					{
+						MessageService.ShowWarning(strValRes);
+						return false;
+					}
 
-				m_pKey.AddUserKey(new KcpPassword(pb));
-				MemUtil.ZeroByteArray(pb);
+					m_pKey.AddUserKey(new KcpPassword(pb));
+				}
+				finally { MemUtil.ZeroByteArray(pb); }
 			}
 
 			string strKeyFile = m_cmbKeyFile.Text;
