@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ using System.Collections.Generic;
 using System.ComponentModel;
 using System.Diagnostics;
 using System.Drawing;
+using System.IO;
 using System.Text;
 using System.Windows.Forms;
 
@@ -67,8 +68,18 @@ namespace KeePass.Forms
 				KPRes.PluginsDesc);
 			this.Icon = AppIcons.Default;
 
+			Debug.Assert(!m_lblCacheSize.AutoSize); // For RTL support
+			m_lblCacheSize.Text += " " + StrUtil.FormatDataSize(
+				PlgxCache.GetUsedCacheSize()) + ".";
+
 			m_cbCacheDeleteOld.Checked = Program.Config.Application.Start.PluginCacheDeleteOld;
 
+			if(string.IsNullOrEmpty(PluginManager.UserDirectory))
+			{
+				Debug.Assert(false);
+				m_btnOpenFolder.Enabled = false;
+			}
+
 			m_lvPlugins.Columns.Add(KPRes.Plugin);
 			m_lvPlugins.Columns.Add(KPRes.Version);
 			m_lvPlugins.Columns.Add(KPRes.Author);
@@ -80,14 +91,9 @@ namespace KeePass.Forms
 			m_ilIcons.ImageSize = new Size(DpiUtil.ScaleIntX(16),
 				DpiUtil.ScaleIntY(16));
 			m_ilIcons.ColorDepth = ColorDepth.Depth32Bit;
-
-			Debug.Assert(!m_lblCacheSize.AutoSize); // For RTL support
-			m_lblCacheSize.Text += " " + StrUtil.FormatDataSize(
-				PlgxCache.GetUsedCacheSize()) + ".";
-
 			m_lvPlugins.SmallImageList = m_ilIcons;
-			UpdatePluginsList();
 
+			UpdatePluginsList();
 			if(m_lvPlugins.Items.Count > 0)
 			{
 				m_lvPlugins.Items[0].Selected = true;
@@ -168,11 +174,6 @@ namespace KeePass.Forms
 			UpdatePluginDescription();
 		}
 
-		private void OnPluginsLinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
-		{
-			WinUtil.OpenUrl(PwDefs.PluginsUrl, null);
-		}
-
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
 		{
 			CleanUpEx();
@@ -191,5 +192,24 @@ namespace KeePass.Forms
 			Program.Config.Application.Start.PluginCacheDeleteOld =
 				m_cbCacheDeleteOld.Checked;
 		}
+
+		private void OnBtnGetMore(object sender, EventArgs e)
+		{
+			WinUtil.OpenUrl(PwDefs.PluginsUrl, null);
+		}
+
+		private void OnBtnOpenFolder(object sender, EventArgs e)
+		{
+			try
+			{
+				string str = PluginManager.UserDirectory;
+				if(string.IsNullOrEmpty(str)) { Debug.Assert(false); return; }
+
+				if(!Directory.Exists(str)) Directory.CreateDirectory(str);
+
+				WinUtil.OpenUrl("cmd://\"" + str + "\"", null, false);
+			}
+			catch(Exception ex) { MessageService.ShowWarning(ex.Message); }
+		}
 	}
 }
