@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,9 @@ using System.Windows.Forms;
 
 using KeePass.App;
 using KeePass.App.Configuration;
-using KeePass.UI;
 using KeePass.Resources;
+using KeePass.UI;
+using KeePass.Util.Spr;
 
 using KeePassLib;
 using KeePassLib.Collections;
@@ -45,24 +46,60 @@ namespace KeePass.Forms
 	public partial class PrintForm : Form
 	{
 		private PwGroup m_pgDataSource = null;
+		private PwDatabase m_pdContext = null;
+		private ImageList m_ilClientIcons = null;
 		private bool m_bPrintMode = true;
 		private int m_nDefaultSortColumn = -1;
 
 		private bool m_bBlockPreviewRefresh = false;
-		private string m_strGeneratedHtml = string.Empty;
+		private Control m_cPreBlock = null;
 
 		private ImageList m_ilTabIcons = null;
 
+		private string m_strGeneratedHtml = string.Empty;
 		public string GeneratedHtml
 		{
 			get { return m_strGeneratedHtml; }
 		}
 
-		public void InitEx(PwGroup pgDataSource, bool bPrintMode, int nDefaultSortColumn)
+		private static string g_strCodeItS = null;
+		private static string g_strCodeItE = null;
+
+		private sealed class PfOptions
+		{
+			public bool MonoPasswords = true;
+			public bool SmallMono = false;
+			public int SprMode = 0;
+
+			public string CellInit = string.Empty;
+			public string CellExit = string.Empty;
+
+			public string FontInit = string.Empty;
+			public string FontExit = string.Empty;
+
+			public bool Rtl = false;
+
+			public PwEntry Entry = null;
+			public PwDatabase Database = null;
+			public ImageList ClientIcons = null;
+			public SprContext SprContext = null;
+
+			public PfOptions() { }
+
+			public PfOptions CloneShallow()
+			{
+				return (PfOptions)this.MemberwiseClone();
+			}
+		}
+
+		public void InitEx(PwGroup pgDataSource, PwDatabase pdContext,
+			ImageList ilClientIcons, bool bPrintMode, int nDefaultSortColumn)
 		{
 			Debug.Assert(pgDataSource != null); if(pgDataSource == null) throw new ArgumentNullException("pgDataSource");
 
 			m_pgDataSource = pgDataSource;
+			m_pdContext = pdContext;
+			m_ilClientIcons = ilClientIcons;
 			m_bPrintMode = bPrintMode;
 			m_nDefaultSortColumn = nDefaultSortColumn;
 		}
@@ -76,7 +113,6 @@ namespace KeePass.Forms
 		private void CreateDialogBanner()
 		{
 			string strTitle, strDesc;
-
 			if(m_bPrintMode)
 			{
 				strTitle = KPRes.Print;
@@ -90,7 +126,6 @@ namespace KeePass.Forms
 
 			BannerFactory.CreateBannerEx(this, m_bannerImage,
 				Properties.Resources.B48x48_FilePrint, strTitle, strDesc);
-
 			this.Text = strTitle;
 		}
 
@@ -122,6 +157,12 @@ namespace KeePass.Forms
 			FontUtil.AssignDefaultBold(m_rbTabular);
 			FontUtil.AssignDefaultBold(m_rbDetails);
 
+			Debug.Assert(!m_cmbSpr.Sorted);
+			m_cmbSpr.Items.Add(KPRes.ReplaceNo);
+			m_cmbSpr.Items.Add(KPRes.Replace + " (" + KPRes.Slow + ")");
+			m_cmbSpr.Items.Add(KPRes.BothForms + " (" + KPRes.Slow + ")");
+			m_cmbSpr.SelectedIndex = 0;
+
 			if(!m_bPrintMode) m_btnOK.Text = KPRes.Export;
 
 			m_bBlockPreviewRefresh = true;
@@ -156,13 +197,13 @@ namespace KeePass.Forms
 
 			Program.TempFilesPool.AddWebBrowserPrintContent();
 
-			UpdateHtmlDocument();
+			UpdateHtmlDocument(true);
 			UpdateUIState();
 		}
 
 		private void OnBtnOK(object sender, EventArgs e)
 		{
-			UpdateHtmlDocument();
+			UpdateHtmlDocument(false);
 
 			if(m_bPrintMode)
 			{
@@ -184,20 +225,70 @@ namespace KeePass.Forms
 
 		private void UpdateUIState()
 		{
-			m_cbAutoType.Enabled = m_cbCustomStrings.Enabled = m_rbDetails.Checked;
+			bool bTabular = m_rbTabular.Checked;
+			bool bDetails = m_rbDetails.Checked;
 
-			if(m_rbTabular.Checked)
+			UIUtil.SetEnabled(m_cbAutoType, bDetails);
+			UIUtil.SetEnabled(m_cbCustomStrings, bDetails);
+			if(bTabular)
 			{
-				m_cbAutoType.Checked = false;
-				m_cbCustomStrings.Checked = false;
+				UIUtil.SetChecked(m_cbAutoType, false);
+				UIUtil.SetChecked(m_cbCustomStrings, false);
 			}
+
+			bool bIcon = m_cbIcon.Checked;
+			if(m_ilClientIcons == null)
+			{
+				UIUtil.SetChecked(m_cbIcon, false);
+				UIUtil.SetEnabled(m_cbIcon, false);
+				bIcon = false;
+			}
+
+			UIUtil.SetEnabled(m_cbTitle, !bIcon);
+			if(bIcon) UIUtil.SetChecked(m_cbTitle, true);
 		}
 
-		private void UpdateHtmlDocument()
+		private void UIBlockInteraction(bool bBlock)
+		{
+			if(bBlock) m_cPreBlock = UIUtil.GetActiveControl(this);
+
+			this.UseWaitCursor = bBlock;
+
+			// this.Enabled = !bBlock; // Prevents wait cursor
+			m_tabMain.Enabled = !bBlock;
+			m_btnConfigPrinter.Enabled = !bBlock;
+			m_btnPrintPreview.Enabled = !bBlock;
+			m_btnOK.Enabled = !bBlock;
+			m_btnCancel.Enabled = !bBlock;
+
+			m_wbMain.Visible = !bBlock;
+
+			if(!bBlock && (m_cPreBlock != null)) UIUtil.SetFocus(m_cPreBlock, this);
+		}
+
+		/* private void ShowWaitDocument()
+		{
+			StringBuilder sbW = new StringBuilder();
+			sbW.AppendLine("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"");
+			sbW.AppendLine("\t\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">");
+			sbW.AppendLine("<html xmlns=\"http://www.w3.org/1999/xhtml\">");
+			sbW.AppendLine("<head>");
+			sbW.AppendLine("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />");
+			sbW.AppendLine("<title>...</title>");
+			sbW.AppendLine("</head><body><br /><br />");
+			sbW.AppendLine("<h1 style=\"text-align: center;\">&#8987;</h1>");
+			sbW.AppendLine("</body></html>");
+
+			try { UIUtil.SetWebBrowserDocument(m_wbMain, sbW.ToString()); }
+			catch(Exception) { Debug.Assert(NativeLib.IsUnix()); } // Throws in Mono 2.0+
+		} */
+
+		private void UpdateHtmlDocument(bool bInitial)
 		{
 			if(m_bBlockPreviewRefresh) return;
-
 			m_bBlockPreviewRefresh = true;
+			if(!bInitial) UIBlockInteraction(true);
+			// ShowWaitDocument();
 
 			PwGroup pgDataSource = m_pgDataSource.CloneDeep();
 
@@ -213,7 +304,53 @@ namespace KeePass.Forms
 			if(strSortFieldName != null)
 				SortGroupEntriesRecursive(pgDataSource, strSortFieldName);
 
-			bool bRtl = (this.RightToLeft == RightToLeft.Yes);
+			bool bGroup = m_cbGroups.Checked;
+			bool bTitle = m_cbTitle.Checked, bUserName = m_cbUser.Checked;
+			bool bPassword = m_cbPassword.Checked, bUrl = m_cbUrl.Checked;
+			bool bNotes = m_cbNotes.Checked;
+			bool bCreation = m_cbCreation.Checked, bLastMod = m_cbLastMod.Checked;
+			// bool bLastAcc = m_cbLastAccess.Checked;
+			bool bExpire = m_cbExpire.Checked;
+			bool bAutoType = m_cbAutoType.Checked;
+			bool bTags = m_cbTags.Checked;
+			bool bCustomStrings = m_cbCustomStrings.Checked;
+			bool bUuid = m_cbUuid.Checked;
+
+			PfOptions p = new PfOptions();
+			p.MonoPasswords = m_cbMonospaceForPasswords.Checked;
+			if(m_rbMonospace.Checked) p.MonoPasswords = false; // Monospace anyway
+			p.SmallMono = m_cbSmallMono.Checked;
+			p.SprMode = m_cmbSpr.SelectedIndex;
+			p.Rtl = (this.RightToLeft == RightToLeft.Yes);
+			p.Database = m_pdContext;
+			if(m_cbIcon.Checked) p.ClientIcons = m_ilClientIcons;
+
+			if(m_rbSerif.Checked)
+			{
+				p.FontInit = "<span class=\"fserif\">";
+				p.FontExit = "</span>";
+			}
+			else if(m_rbSansSerif.Checked)
+			{
+				p.FontInit = string.Empty;
+				p.FontExit = string.Empty;
+			}
+			else if(m_rbMonospace.Checked)
+			{
+				p.FontInit = (p.SmallMono ? "<code><small>" : "<code>");
+				p.FontExit = (p.SmallMono ? "</small></code>" : "</code>");
+			}
+			else { Debug.Assert(false); }
+
+			GFunc<string, string> h = new GFunc<string, string>(StrUtil.StringToHtml);
+			GFunc<string, string> c = delegate(string strRaw)
+			{
+				return CompileText(strRaw, p, true, false);
+			};
+			GFunc<string, string> cs = delegate(string strRaw)
+			{
+				return CompileText(strRaw, p, true, true);
+			};
 
 			StringBuilder sb = new StringBuilder();
 
@@ -223,21 +360,22 @@ namespace KeePass.Forms
 			sb.Append("<html xmlns=\"http://www.w3.org/1999/xhtml\"");
 			string strLang = Program.Translation.Properties.Iso6391Code;
 			if(string.IsNullOrEmpty(strLang)) strLang = "en";
-			strLang = StrUtil.StringToHtml(strLang);
+			strLang = h(strLang);
 			sb.Append(" lang=\"" + strLang + "\" xml:lang=\"" + strLang + "\"");
-			if(bRtl) sb.Append(" dir=\"rtl\"");
+			if(p.Rtl) sb.Append(" dir=\"rtl\"");
 			sb.AppendLine(">");
 
 			sb.AppendLine("<head>");
 			sb.AppendLine("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />");
 			sb.Append("<title>");
-			sb.Append(StrUtil.StringToHtml(pgDataSource.Name));
+			sb.Append(h(pgDataSource.Name));
 			sb.AppendLine("</title>");
 			sb.AppendLine("<meta http-equiv=\"expires\" content=\"0\" />");
 			sb.AppendLine("<meta http-equiv=\"cache-control\" content=\"no-cache\" />");
 			sb.AppendLine("<meta http-equiv=\"pragma\" content=\"no-cache\" />");
 
-			sb.AppendLine("<style type=\"text/css\"><!--");
+			sb.AppendLine("<style type=\"text/css\">");
+			sb.AppendLine("/* <![CDATA[ */");
 
 			sb.AppendLine("body, p, div, h1, h2, h3, h4, h5, h6, ol, ul, li, td, th, dd, dt, a {");
 			sb.AppendLine("\tfont-family: \"Tahoma\", \"MS Sans Serif\", \"Sans Serif\", \"Verdana\", sans-serif;");
@@ -273,13 +411,13 @@ namespace KeePass.Forms
 			sb.AppendLine("}");
 
 			sb.AppendLine("th {");
-			sb.AppendLine("\ttext-align: " + (bRtl ? "right;" : "left;"));
+			sb.AppendLine("\ttext-align: " + (p.Rtl ? "right;" : "left;"));
 			sb.AppendLine("\tvertical-align: top;");
 			sb.AppendLine("\tfont-weight: bold;");
 			sb.AppendLine("}");
 
 			sb.AppendLine("td {");
-			sb.AppendLine("\ttext-align: " + (bRtl ? "right;" : "left;"));
+			sb.AppendLine("\ttext-align: " + (p.Rtl ? "right;" : "left;"));
 			sb.AppendLine("\tvertical-align: top;");
 			sb.AppendLine("}");
 
@@ -312,55 +450,42 @@ namespace KeePass.Forms
 			sb.AppendLine("\tword-wrap: break-word;");
 			sb.AppendLine("}");
 
+			sb.AppendLine(".icon_cli {");
+			sb.AppendLine("\tdisplay: inline-block;");
+			sb.AppendLine("\tmargin: 0px 0px 0px 0px;");
+			sb.AppendLine("\tpadding: 0px 0px 0px 0px;");
+			sb.AppendLine("\tborder: 0px none;");
+			sb.AppendLine("\twidth: 1.1em;");
+			sb.AppendLine("\theight: 1.1em;");
+			sb.AppendLine("\tvertical-align: top;");
+			sb.AppendLine("}");
+
 			// Add the temporary content identifier
 			sb.AppendLine("." + Program.TempFilesPool.TempContentTag + " {");
 			sb.AppendLine("\tfont-size: 10pt;");
 			sb.AppendLine("}");
 
-			sb.AppendLine("--></style>");
+			sb.AppendLine("/* ]]> */");
+			sb.AppendLine("</style>");
 			sb.AppendLine("</head><body>");
 
-			sb.AppendLine("<h2>" + StrUtil.StringToHtml(pgDataSource.Name) + "</h2>");
+			sb.AppendLine("<h2>" + h(pgDataSource.Name) + "</h2>");
+			WriteGroupNotes(sb, pgDataSource);
+
+			EntryHandler ehInit = delegate(PwEntry pe)
+			{
+				p.Entry = pe;
+
+				if(p.SprMode != 0)
+					p.SprContext = new SprContext(pe, p.Database,
+						SprCompileFlags.NonActive, false, false);
+				else { Debug.Assert(p.SprContext == null); }
+
+				Application.DoEvents();
+				return true;
+			};
 
-			GroupHandler gh = null;
 			EntryHandler eh = null;
-
-			bool bGroup = m_cbGroups.Checked;
-			bool bTitle = m_cbTitle.Checked, bUserName = m_cbUser.Checked;
-			bool bPassword = m_cbPassword.Checked, bURL = m_cbUrl.Checked;
-			bool bNotes = m_cbNotes.Checked;
-			bool bCreation = m_cbCreation.Checked, bLastMod = m_cbLastMod.Checked;
-			// bool bLastAcc = m_cbLastAccess.Checked;
-			bool bExpire = m_cbExpire.Checked;
-			bool bAutoType = m_cbAutoType.Checked;
-			bool bTags = m_cbTags.Checked;
-			bool bCustomStrings = m_cbCustomStrings.Checked;
-			bool bUuid = m_cbUuid.Checked;
-
-			bool bMonoPasswords = m_cbMonospaceForPasswords.Checked;
-			if(m_rbMonospace.Checked) bMonoPasswords = false; // Monospaced anyway
-
-			bool bSmallMono = m_cbSmallMono.Checked;
-
-			string strFontInit = string.Empty, strFontExit = string.Empty;
-
-			if(m_rbSerif.Checked)
-			{
-				strFontInit = "<span class=\"fserif\">";
-				strFontExit = "</span>";
-			}
-			else if(m_rbSansSerif.Checked)
-			{
-				strFontInit = string.Empty;
-				strFontExit = string.Empty;
-			}
-			else if(m_rbMonospace.Checked)
-			{
-				strFontInit = (bSmallMono ? "<code><small>" : "<code>");
-				strFontExit = (bSmallMono ? "</small></code>" : "</code>");
-			}
-			else { Debug.Assert(false); }
-
 			string strTableInit = "<table>";
 			PwGroup pgLast = null;
 
@@ -371,7 +496,7 @@ namespace KeePass.Forms
 				if(bTitle) ++nEquiCols;
 				if(bUserName) ++nEquiCols;
 				if(bPassword) ++nEquiCols;
-				if(bURL) ++nEquiCols;
+				if(bUrl) ++nEquiCols;
 				if(bNotes) nEquiCols += 2;
 				if(bCreation) ++nEquiCols;
 				// if(bLastAcc) ++nEquiCols;
@@ -391,25 +516,27 @@ namespace KeePass.Forms
 				string strHTdInit2 = "<th class=\"field_name\" style=\"width: " +
 					strColWidth2 + "%;\">";
 				string strHTdExit = "</th>";
+				string strDataTdInit = "<td class=\"field_data\">";
+				string strDataTdExit = "</td>";
 
-				string strCellPre = "<td class=\"field_data\">" + strFontInit;
-				string strCellPost = strFontExit + "</td>";
+				p.CellInit = strDataTdInit + p.FontInit;
+				p.CellExit = p.FontExit + strDataTdExit;
 
 				StringBuilder sbH = new StringBuilder();
 				sbH.AppendLine();
 				sbH.Append("<tr>");
-				if(bGroup) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.Group) + strHTdExit);
-				if(bTitle) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.Title) + strHTdExit);
-				if(bUserName) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.UserName) + strHTdExit);
-				if(bPassword) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.Password) + strHTdExit);
-				if(bURL) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.Url) + strHTdExit);
-				if(bNotes) sbH.AppendLine(strHTdInit2 + StrUtil.StringToHtml(KPRes.Notes) + strHTdExit);
-				if(bCreation) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.CreationTime) + strHTdExit);
-				// if(bLastAcc) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.LastAccessTime) + strHTdExit);
-				if(bLastMod) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.LastModificationTime) + strHTdExit);
-				if(bExpire) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.ExpiryTime) + strHTdExit);
-				if(bTags) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.Tags) + strHTdExit);
-				if(bUuid) sbH.AppendLine(strHTdInit + StrUtil.StringToHtml(KPRes.Uuid) + strHTdExit);
+				if(bGroup) sbH.AppendLine(strHTdInit + h(KPRes.Group) + strHTdExit);
+				if(bTitle) sbH.AppendLine(strHTdInit + h(KPRes.Title) + strHTdExit);
+				if(bUserName) sbH.AppendLine(strHTdInit + h(KPRes.UserName) + strHTdExit);
+				if(bPassword) sbH.AppendLine(strHTdInit + h(KPRes.Password) + strHTdExit);
+				if(bUrl) sbH.AppendLine(strHTdInit + h(KPRes.Url) + strHTdExit);
+				if(bNotes) sbH.AppendLine(strHTdInit2 + h(KPRes.Notes) + strHTdExit);
+				if(bCreation) sbH.AppendLine(strHTdInit + h(KPRes.CreationTime) + strHTdExit);
+				// if(bLastAcc) sbH.AppendLine(strHTdInit + h(KPRes.LastAccessTime) + strHTdExit);
+				if(bLastMod) sbH.AppendLine(strHTdInit + h(KPRes.LastModificationTime) + strHTdExit);
+				if(bExpire) sbH.AppendLine(strHTdInit + h(KPRes.ExpiryTime) + strHTdExit);
+				if(bTags) sbH.AppendLine(strHTdInit + h(KPRes.Tags) + strHTdExit);
+				if(bUuid) sbH.AppendLine(strHTdInit + h(KPRes.Uuid) + strHTdExit);
 				sbH.Append("</tr>"); // No terminating \r\n
 
 				strTableInit += sbH.ToString();
@@ -417,48 +544,49 @@ namespace KeePass.Forms
 
 				eh = delegate(PwEntry pe)
 				{
+					ehInit(pe);
+
 					sb.AppendLine("<tr>");
 
-					WriteTabularIf(bGroup, sb, StrUtil.StringToHtml(pe.ParentGroup.Name), strCellPre, strCellPost);
-					WriteTabularIf(bTitle, sb, pe, PwDefs.TitleField, strCellPre, strCellPost);
-					WriteTabularIf(bUserName, sb, pe, PwDefs.UserNameField, strCellPre, strCellPost);
+					WriteTabularIf(bGroup, sb, c(pe.ParentGroup.Name), p);
+					WriteTabularIf(bTitle, sb, pe, PwDefs.TitleField, p);
+					WriteTabularIf(bUserName, sb, pe, PwDefs.UserNameField, p);
 
 					if(bPassword)
 					{
-						if(bMonoPasswords)
-							sb.Append("<td class=\"field_data\">" + (bSmallMono ?
+						if(p.MonoPasswords)
+							sb.Append(strDataTdInit + (p.SmallMono ?
 								"<code><small>" : "<code>"));
-						else sb.Append(strCellPre);
+						else sb.Append(p.CellInit);
 
-						string strInner = StrUtil.StringToHtml(pe.Strings.ReadSafe(PwDefs.PasswordField));
-						if(strInner.Length > 0) sb.Append(strInner);
-						else sb.Append(@"&nbsp;");
+						string strInner = cs(pe.Strings.ReadSafe(PwDefs.PasswordField));
+						if(strInner.Length == 0) strInner = "&nbsp;";
+						sb.Append(strInner);
 
-						if(bMonoPasswords)
-							sb.AppendLine(bSmallMono ? "</small></code></td>" : "</code></td>");
-						else sb.AppendLine(strCellPost);
+						if(p.MonoPasswords)
+							sb.AppendLine((p.SmallMono ? "</small></code>" :
+								"</code>") + strDataTdExit);
+						else sb.AppendLine(p.CellExit);
 					}
 
-					// WriteTabularIf(bURL, sb, pe, PwDefs.UrlField, strCellPre, strCellPost);
-					WriteTabularIf(bURL, sb, MakeUrlLink(pe.Strings.ReadSafe(PwDefs.UrlField),
-						strFontInit, strFontExit), strCellPre, strCellPost);
+					// WriteTabularIf(bUrl, sb, pe, PwDefs.UrlField, p);
+					WriteTabularIf(bUrl, sb, MakeUrlLink(pe.Strings.ReadSafe(
+						PwDefs.UrlField), p), p);
 
-					WriteTabularIf(bNotes, sb, pe, PwDefs.NotesField, strCellPre, strCellPost);
+					WriteTabularIf(bNotes, sb, pe, PwDefs.NotesField, p);
 
-					WriteTabularIf(bCreation, sb, StrUtil.StringToHtml(
-						TimeUtil.ToDisplayString(pe.CreationTime)), strCellPre, strCellPost);
-					// WriteTabularIf(bLastAcc, sb, StrUtil.StringToHtml(
-					//	TimeUtil.ToDisplayString(pe.LastAccessTime)), strCellPre, strCellPost);
-					WriteTabularIf(bLastMod, sb, StrUtil.StringToHtml(
-						TimeUtil.ToDisplayString(pe.LastModificationTime)), strCellPre, strCellPost);
-					WriteTabularIf(bExpire, sb, StrUtil.StringToHtml(pe.Expires ?
-						TimeUtil.ToDisplayString(pe.ExpiryTime) : KPRes.NeverExpires),
-						strCellPre, strCellPost);
+					WriteTabularIf(bCreation, sb, h(TimeUtil.ToDisplayString(
+						pe.CreationTime)), p);
+					// WriteTabularIf(bLastAcc, sb, h(TimeUtil.ToDisplayString(
+					//	pe.LastAccessTime)), p);
+					WriteTabularIf(bLastMod, sb, h(TimeUtil.ToDisplayString(
+						pe.LastModificationTime)), p);
+					WriteTabularIf(bExpire, sb, h(pe.Expires ? TimeUtil.ToDisplayString(
+						pe.ExpiryTime) : KPRes.NeverExpires), p);
 
-					WriteTabularIf(bTags, sb, StrUtil.StringToHtml(StrUtil.TagsToString(
-						pe.Tags, true)), strCellPre, strCellPost);
+					WriteTabularIf(bTags, sb, h(StrUtil.TagsToString(pe.Tags, true)), p);
 
-					WriteTabularIf(bUuid, sb, pe.Uuid.ToHexString(), strCellPre, strCellPost);
+					WriteTabularIf(bUuid, sb, pe.Uuid.ToHexString(), p);
 
 					sb.AppendLine("</tr>");
 					return true;
@@ -473,42 +601,54 @@ namespace KeePass.Forms
 
 				eh = delegate(PwEntry pe)
 				{
+					ehInit(pe);
+
 					if((pgLast != null) && (pgLast == pe.ParentGroup))
 						sb.AppendLine("<tr><td colspan=\"2\"><hr /></td></tr>");
 
-					if(bGroup) WriteDetailsLine(sb, KPRes.Group, pe.ParentGroup.Name, bSmallMono, bMonoPasswords, strFontInit, strFontExit);
-					if(bTitle) WriteDetailsLine(sb, KPRes.Title, pe.Strings.ReadSafe(PwDefs.TitleField), bSmallMono, bMonoPasswords, strFontInit + "<b>", "</b>" + strFontExit);
-					if(bUserName) WriteDetailsLine(sb, KPRes.UserName, pe.Strings.ReadSafe(PwDefs.UserNameField), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
-					if(bPassword) WriteDetailsLine(sb, KPRes.Password, pe.Strings.ReadSafe(PwDefs.PasswordField), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
-					if(bURL) WriteDetailsLine(sb, KPRes.Url, pe.Strings.ReadSafe(PwDefs.UrlField), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
-					if(bNotes) WriteDetailsLine(sb, KPRes.Notes, pe.Strings.ReadSafe(PwDefs.NotesField), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
+					if(bGroup) WriteDetailsLine(sb, KPRes.Group, pe.ParentGroup.Name, p);
+					if(bTitle)
+					{
+						PfOptions pSub = p.CloneShallow();
+						pSub.FontInit = MakeIconImg(pe.IconId, pe.CustomIconUuid, p) +
+							pSub.FontInit + "<b>";
+						pSub.FontExit = "</b>" + pSub.FontExit;
+
+						WriteDetailsLine(sb, KPRes.Title, pe.Strings.ReadSafe(
+							PwDefs.TitleField), pSub);
+					}
+					if(bUserName) WriteDetailsLine(sb, KPRes.UserName, pe.Strings.ReadSafe(
+						PwDefs.UserNameField), p);
+					if(bPassword) WriteDetailsLine(sb, KPRes.Password, pe.Strings.ReadSafe(
+						PwDefs.PasswordField), p);
+					if(bUrl) WriteDetailsLine(sb, KPRes.Url, pe.Strings.ReadSafe(
+						PwDefs.UrlField), p);
+					if(bNotes) WriteDetailsLine(sb, KPRes.Notes, pe.Strings.ReadSafe(
+						PwDefs.NotesField), p);
 					if(bCreation) WriteDetailsLine(sb, KPRes.CreationTime, TimeUtil.ToDisplayString(
-						pe.CreationTime), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
+						pe.CreationTime), p);
 					// if(bLastAcc) WriteDetailsLine(sb, KPRes.LastAccessTime, TimeUtil.ToDisplayString(
-					//	pe.LastAccessTime), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
+					//	pe.LastAccessTime), p);
 					if(bLastMod) WriteDetailsLine(sb, KPRes.LastModificationTime, TimeUtil.ToDisplayString(
-						pe.LastModificationTime), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
+						pe.LastModificationTime), p);
 					if(bExpire) WriteDetailsLine(sb, KPRes.ExpiryTime, (pe.Expires ? TimeUtil.ToDisplayString(
-						pe.ExpiryTime) : KPRes.NeverExpires), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
+						pe.ExpiryTime) : KPRes.NeverExpires), p);
 
 					if(bAutoType)
 					{
 						foreach(AutoTypeAssociation a in pe.AutoType.Associations)
 							WriteDetailsLine(sb, KPRes.AutoType, a.WindowName +
-								": " + a.Sequence, bSmallMono, bMonoPasswords,
-								strFontInit, strFontExit);
+								": " + a.Sequence, p);
 					}
 
 					if(bTags) WriteDetailsLine(sb, KPRes.Tags, StrUtil.TagsToString(
-						pe.Tags, true), bSmallMono, bMonoPasswords, strFontInit, strFontExit);
-					if(bUuid) WriteDetailsLine(sb, KPRes.Uuid, pe.Uuid.ToHexString(),
-						bSmallMono, bMonoPasswords, strFontInit, strFontExit);
+						pe.Tags, true), p);
+					if(bUuid) WriteDetailsLine(sb, KPRes.Uuid, pe.Uuid.ToHexString(), p);
 
 					foreach(KeyValuePair<string, ProtectedString> kvp in pe.Strings)
 					{
 						if(bCustomStrings && !PwDefs.IsStandardField(kvp.Key))
-							WriteDetailsLine(sb, kvp, bSmallMono, bMonoPasswords,
-								strFontInit, strFontExit);
+							WriteDetailsLine(sb, kvp, p);
 					}
 
 					pgLast = pe.ParentGroup;
@@ -517,13 +657,15 @@ namespace KeePass.Forms
 			}
 			else { Debug.Assert(false); }
 
-			gh = delegate(PwGroup pg)
+			GroupHandler gh = delegate(PwGroup pg)
 			{
 				if(pg.Entries.UCount == 0) return true;
 
 				sb.Append("</table><br /><br /><h3>"); // "</table><br /><hr /><h3>"
-				sb.Append(StrUtil.StringToHtml(pg.GetFullPath(" - ", false)));
+				// sb.Append(MakeIconImg(pg.IconId, pg.CustomIconUuid, p));
+				sb.Append(h(pg.GetFullPath(" - ", false)));
 				sb.AppendLine("</h3>");
+				WriteGroupNotes(sb, pg);
 				sb.AppendLine(strTableInit);
 
 				return true;
@@ -543,39 +685,68 @@ namespace KeePass.Forms
 			try { m_wbMain.AllowNavigation = false; }
 			catch(Exception) { Debug.Assert(false); }
 
+			if(!bInitial) UIBlockInteraction(false);
 			m_bBlockPreviewRefresh = false;
 		}
 
-		private static void WriteTabularIf(bool bCondition, StringBuilder sb,
-			PwEntry pe, string strIndex, string strCellPre, string strCellPost)
+		private static string CompileText(string strText, PfOptions p, bool bToHtml,
+			bool bNbsp)
 		{
-			if(!bCondition) return;
+			string str = strText;
 
-			sb.Append(strCellPre);
+			if(g_strCodeItS == null)
+			{
+				g_strCodeItS = (new PwUuid(true)).ToHexString();
+				g_strCodeItE = (new PwUuid(true)).ToHexString();
+			}
 
-			string strInner = StrUtil.StringToHtml(pe.Strings.ReadSafe(strIndex));
-			if(strInner.Length > 0) sb.Append(strInner);
-			else sb.Append(@"&nbsp;");
+			if((p.SprMode != 0) && (p.SprContext != null))
+			{
+				string strPre = str;
+				str = SprEngine.Compile(str, p.SprContext);
 
-			sb.AppendLine(strCellPost);
+				if((p.SprMode == 2) && (str != strPre))
+				{
+					if(bToHtml) str += " - " + g_strCodeItS + strPre + g_strCodeItE;
+					else str += " - " + strPre;
+				}
+			}
+
+			if(bToHtml) str = StrUtil.StringToHtml(str, bNbsp);
+
+			str = str.Replace(g_strCodeItS, "<i>");
+			str = str.Replace(g_strCodeItE, "</i>");
+			return str;
 		}
 
 		private static void WriteTabularIf(bool bCondition, StringBuilder sb,
-			string strValue, string strCellPre, string strCellPost)
+			PwEntry pe, string strField, PfOptions p)
 		{
 			if(!bCondition) return;
 
-			sb.Append(strCellPre);
+			string str = CompileText(pe.Strings.ReadSafe(strField), p, true, false);
+
+			if(strField == PwDefs.TitleField)
+				str = MakeIconImg(pe.IconId, pe.CustomIconUuid, p) + str;
+
+			WriteTabularIf(bCondition, sb, str, p);
+		}
+
+		private static void WriteTabularIf(bool bCondition, StringBuilder sb,
+			string strValue, PfOptions p)
+		{
+			if(!bCondition) return;
+
+			sb.Append(p.CellInit);
 
 			if(strValue.Length > 0) sb.Append(strValue); // Don't HTML-encode
 			else sb.Append(@"&nbsp;");
 
-			sb.AppendLine(strCellPost);
+			sb.AppendLine(p.CellExit);
 		}
 
 		private static void WriteDetailsLine(StringBuilder sb,
-			KeyValuePair<string, ProtectedString> kvp, bool bSmallMono,
-			bool bMonoPasswords, string strFontInit, string strFontExit)
+			KeyValuePair<string, ProtectedString> kvp, PfOptions p)
 		{
 			sb.Append("<tr><td class=\"field_name\" style=\"width: 20%;\"><i>");
 			sb.Append(StrUtil.StringToHtml(kvp.Key));
@@ -583,50 +754,105 @@ namespace KeePass.Forms
 
 			sb.Append("<td class=\"field_data\" style=\"width: 80%;\">");
 
-			if(bMonoPasswords && (kvp.Key == PwDefs.PasswordField))
-				sb.Append(bSmallMono ? "<code><small>" : "<code>");
-			else sb.Append(strFontInit);
+			bool bPassword = (kvp.Key == PwDefs.PasswordField);
+			bool bCode = (p.MonoPasswords && bPassword);
+
+			if(bCode) sb.Append(p.SmallMono ? "<code><small>" : "<code>");
+			else sb.Append(p.FontInit);
 
 			if((kvp.Key == PwDefs.UrlField) && !kvp.Value.IsEmpty)
-				sb.Append(MakeUrlLink(kvp.Value.ReadString(), strFontInit, strFontExit));
+				sb.Append(MakeUrlLink(kvp.Value.ReadString(), p));
 			else
 			{
-				string strInner = StrUtil.StringToHtml(kvp.Value.ReadString());
-				if(strInner.Length > 0) sb.Append(strInner);
-				else sb.Append("&nbsp;");
+				string strInner = CompileText(kvp.Value.ReadString(), p,
+					true, bPassword);
+				if(strInner.Length == 0) strInner = "&nbsp;";
+				sb.Append(strInner);
 			}
 
-			if(kvp.Key == PwDefs.PasswordField)
-				sb.Append(bSmallMono ? "</small></code>" : "</code>");
-			else sb.Append(strFontExit);
+			if(bCode) sb.Append(p.SmallMono ? "</small></code>" : "</code>");
+			else sb.Append(p.FontExit);
 
 			sb.AppendLine("</td></tr>");
 		}
 
 		private static void WriteDetailsLine(StringBuilder sb, string strIndex,
-			string strValue, bool bSmallMono, bool bMonoPasswords, string strFontInit,
-			string strFontExit)
+			string strValue, PfOptions p)
 		{
 			if(string.IsNullOrEmpty(strValue)) return;
 
-			KeyValuePair<string, ProtectedString> kvp = new KeyValuePair<string, ProtectedString>(strIndex,
-				new ProtectedString(false, strValue));
-
-			WriteDetailsLine(sb, kvp, bSmallMono, bMonoPasswords, strFontInit, strFontExit);
+			KeyValuePair<string, ProtectedString> kvp = new KeyValuePair<string, ProtectedString>(
+				strIndex, new ProtectedString(false, strValue));
+			WriteDetailsLine(sb, kvp, p);
 		}
 
-		private static string MakeUrlLink(string strRawUrl, string strFontInit,
-			string strFontExit)
+		private static string MakeIconImg(PwIcon i, PwUuid ci, PfOptions p)
+		{
+			if(p.ClientIcons == null) return string.Empty;
+
+			Image img = null;
+
+			PwDatabase pd = p.Database;
+			if((ci != null) && !ci.Equals(PwUuid.Zero) && (pd != null))
+			{
+				int cix = pd.GetCustomIconIndex(ci);
+				if(cix >= 0)
+				{
+					cix += (int)PwIcon.Count;
+					if(cix < p.ClientIcons.Images.Count)
+						img = p.ClientIcons.Images[cix];
+					else { Debug.Assert(false); }
+				}
+				else { Debug.Assert(false); }
+			}
+
+			int ix = (int)i;
+			if((img == null) && (ix >= 0) && (ix < p.ClientIcons.Images.Count))
+				img = p.ClientIcons.Images[ix];
+
+			string strData = GfxUtil.ImageToDataUri(img);
+			if(string.IsNullOrEmpty(strData)) { Debug.Assert(false); return string.Empty; }
+
+			StringBuilder sb = new StringBuilder();
+			sb.Append("<img src=\"");
+			sb.Append(strData);
+			sb.AppendLine("\"");
+			sb.Append("class=\"icon_cli\" alt=\"\" />&nbsp;");
+
+			return sb.ToString();
+		}
+
+		private static string MakeUrlLink(string strRawUrl, PfOptions p)
 		{
 			if(string.IsNullOrEmpty(strRawUrl)) return string.Empty;
 
-			string strUrl = StrUtil.StringToHtml(strRawUrl);
-			strUrl = "<a href=\"" + strUrl + "\">" + strFontInit + strUrl +
-				strFontExit + "</a>";
-			return strUrl;
+			string strCmp = CompileText(strRawUrl, p, true, false);
+
+			string strHRef = strCmp;
+			if(p.SprMode == 2) // Use only Spr-compiled URL for HRef, not both
+			{
+				PfOptions pSub = p.CloneShallow();
+				pSub.SprMode = 1;
+				strHRef = CompileText(strRawUrl, pSub, true, false);
+			}
+			// Do not Spr-compile URL for HRef when p.SprMode == 0, because
+			// this could unexpectedly disclose external data
+
+			return ("<a href=\"" + strHRef + "\">" + p.FontInit + strCmp +
+				p.FontExit + "</a>");
 		}
 
-		private void SortGroupEntriesRecursive(PwGroup pg, string strFieldName)
+		private static void WriteGroupNotes(StringBuilder sb, PwGroup pg)
+		{
+			string str = pg.Notes.Trim();
+			if(str.Length == 0) return;
+
+			// No <p>...</p> due to padding/margin
+			sb.AppendLine("<table><tr><td>" + StrUtil.StringToHtml(str) +
+				"</td></tr></table><br />");
+		}
+
+		private static void SortGroupEntriesRecursive(PwGroup pg, string strFieldName)
 		{
 			PwEntryComparer cmp = new PwEntryComparer(strFieldName, true, true);
 			pg.Entries.Sort(cmp);
@@ -639,7 +865,7 @@ namespace KeePass.Forms
 
 		private void OnBtnConfigPage(object sender, EventArgs e)
 		{
-			UpdateHtmlDocument();
+			UpdateHtmlDocument(false);
 
 			try { m_wbMain.ShowPageSetupDialog(); } // Throws in Mono 1.2.6+
 			catch(NotImplementedException)
@@ -651,7 +877,7 @@ namespace KeePass.Forms
 
 		private void OnBtnPrintPreview(object sender, EventArgs e)
 		{
-			UpdateHtmlDocument();
+			UpdateHtmlDocument(false);
 
 			try { m_wbMain.ShowPrintPreviewDialog(); } // Throws in Mono 1.2.6+
 			catch(NotImplementedException)
@@ -663,7 +889,7 @@ namespace KeePass.Forms
 
 		private void OnTabSelectedIndexChanged(object sender, EventArgs e)
 		{
-			if(m_tabMain.SelectedIndex == 0) UpdateHtmlDocument();
+			if(m_tabMain.SelectedIndex == 0) UpdateHtmlDocument(false);
 		}
 
 		private void OnTabularCheckedChanged(object sender, EventArgs e)
@@ -677,7 +903,7 @@ namespace KeePass.Forms
 				m_cbTitle, m_cbUser, m_cbPassword, m_cbUrl, m_cbNotes,
 				m_cbCreation, m_cbLastMod, m_cbExpire, // m_cbLastAccess
 				m_cbAutoType, m_cbTags,
-				m_cbGroups, m_cbCustomStrings, m_cbUuid
+				m_cbIcon, m_cbCustomStrings, m_cbGroups, m_cbUuid
 			};
 		}
 
@@ -705,5 +931,15 @@ namespace KeePass.Forms
 
 			GlobalWindowManager.RemoveWindow(this);
 		}
+
+		private void OnFormClosing(object sender, FormClosingEventArgs e)
+		{
+			if(m_bBlockPreviewRefresh) e.Cancel = true;
+		}
+
+		private void OnIconCheckedChanged(object sender, EventArgs e)
+		{
+			UpdateUIState();
+		}
 	}
-}
\ No newline at end of file
+}
