@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,10 +19,10 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
+using System.Diagnostics;
 using System.Drawing;
 using System.IO;
-using System.Diagnostics;
+using System.Text;
 using System.Xml;
 
 using KeePass.Util;
@@ -132,7 +132,7 @@ namespace KeePass.UI
 
 			FontStyle fs = FontStyle.Regular;
 			if(v[4] == "75") fs |= FontStyle.Bold;
-			if(v[5] == "2") fs |= FontStyle.Italic;
+			if((v[5] == "1") || (v[5] == "2")) fs |= FontStyle.Italic;
 
 			return FontUtil.CreateFont(v[0], fSize, fs);
 		}
