@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -150,7 +150,7 @@ namespace KeePass.Util
 			if(strFill == null) return str; // No assert
 
 			string strRep;
-			if((ctx != null) && ctx.EncodeQuotesForCommandLine)
+			if((ctx != null) && ctx.EncodeForCommandLine)
 				strRep = "\"" + SprEngine.TransformContent(strFill, ctx) + "\"";
 			else
 				strRep = SprEngine.TransformContent("\"" + strFill + "\"", ctx);
