@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -280,7 +280,7 @@ namespace KeePassLib.Utility
 		{
 			++m_uCurrentMessageCount;
 
-			string strTitle = PwDefs.ShortProductName + @" - " + KLRes.FatalError;
+			string strTitle = PwDefs.ShortProductName + " - " + KLRes.FatalError;
 			string strText = KLRes.FatalErrorText + MessageService.NewParagraph +
 				KLRes.ErrorInClipboard + MessageService.NewParagraph +
 				// Please send it to the KeePass developers.
